@@ -1,23 +1,23 @@
-from PySide2.QtWidgets import *
-from PySide2.QtGui import *
-from PySide2.QtCore import *
-from CIDAN.GUI.Data_Interaction.Signals import *
+import sys
+
 from CIDAN.GUI.Data_Interaction.Thread import Thread
 
 
 class PreprocessThread(Thread):
-    def __init__(self, main_widget, button):
+    def __init__(self, main_widget, button, preprocess_tab):
         super().__init__(main_widget.data_handler)
         self.main_widget = main_widget
         self.button = button
+        self.preprocess_tab = preprocess_tab
         self.signal.sig.connect(lambda x: self.endThread(x))
 
     def run(self):
         try:
-            self.signal.sig.emit(self.data_handler.calculate_filters())
+            self.data_handler.calculate_filters()
+            self.signal.sig.emit(True)
         except:
             print("Unexpected error:", sys.exc_info()[0])
-            self.signal.sig.emit(np.matrix([0]))
+            self.signal.sig.emit(False)
 
     def runThread(self):
 
@@ -27,10 +27,12 @@ class PreprocessThread(Thread):
             self.start()
         else:
             print(
-                "Previous process in process, please wait to start new one till finished")
+                "Previous process in process, please wait to start new one till "
+                "finished")
 
-    def endThread(self, image_data):
+    def endThread(self, success):
         self.button.setEnabled(True)
-        if image_data.shape != [1]:
+        if success:
             print("Finished preprocessing sequence")
-            self.main_widget.preprocess_image_view.setImage(image_data)
+            self.preprocess_tab.set_image_display_list(self.data_handler.trials_loaded,
+                                                       self.data_handler.dataset_trials_filtered_loaded)
