@@ -1,12 +1,12 @@
-from PySide2.QtWidgets import *
-from PySide2.QtGui import *
 import numpy as np
 from PySide2.QtCore import *
+
+
 class MatrixSignal(QObject):
     def __init__(self):
         super().__init__()
 
-    sig = Signal(np.matrix)
+    sig = Signal(np.ndarray)
 
 
 class StrSignal(QObject):
@@ -20,4 +20,4 @@ class BoolSignal(QObject):
     def __init__(self):
         super().__init__()
 
-    sig = Signal(bool)
\ No newline at end of file
+    sig = Signal(bool)
