@@ -1,8 +1,12 @@
-from CIDAN.GUI.Data_Interaction.DataHandler import DataHandler
-
-from CIDAN.GUI.Inputs.FileInput import createFileDialog
 import logging
-logger1 = logging.getLogger("CIDAN.fileHandling")
+import os
+
+from CIDAN.GUI.Data_Interaction.DataHandler import DataHandler
+from CIDAN.GUI.Inputs.FileInput import createFileDialog
+
+logger1 = logging.getLogger("CIDAN.loadDataset")
+
+
 # def loadImageWrapper(main_widget):
 #     def loadImage():
 #         path_to_file = createFileDialog("~/Desktop", forOpen=True, fmt='', isFolder=0)
@@ -18,8 +22,7 @@ logger1 = logging.getLogger("CIDAN.fileHandling")
 #     return loadImage
 
 
-
-def load_new_dataset(main_widget, file_input, save_dir_input,trials=None):
+def load_new_dataset(main_widget, file_input, save_dir_input, trials=None):
     print(trials)
     file_path = file_input.current_state()
     save_dir_path = save_dir_input.current_state()
@@ -27,27 +30,28 @@ def load_new_dataset(main_widget, file_input, save_dir_input,trials=None):
     #     main_widget.data_handler.__del__()
     if not trials:
         try:
-
-            main_widget.data_handler = DataHandler(data_path=file_path,trials=[""],
+            dir_path = os.path.dirname(file_path)
+            main_widget.data_handler = DataHandler(data_path=dir_path,
+                                                   trials=[os.path.basename(file_path)],
                                                    save_dir_path=save_dir_path,
-                                               save_dir_already_created=False)
+                                                   save_dir_already_created=False)
             main_widget.init_w_data()
-        except Exception as e:
+        except IndentationError as e:
             logger1.error(e)
             print("Loading Failed please make sure it is a valid file")
     if trials:
-        logger1.debug("Trials:"+str(trials))
+        logger1.debug("Trials:" + str(trials))
         if len(trials) == 0:
             print("Please select at least one trial")
         try:
             main_widget.data_handler = DataHandler(data_path=file_path, trials=trials,
-                                               save_dir_path=save_dir_path,
-                                               save_dir_already_created=False)
+                                                   save_dir_path=save_dir_path,
+                                                   save_dir_already_created=False)
             main_widget.init_w_data()
-        except Exception as e:
+        except IndentationError as e:
             logger1.error(e)
             print("Loading Failed please make sure it is a valid folder and all trials"
-                  + "are valid files")
+                  + " are valid files")
 
 
 def load_prev_session(main_widget, save_dir_input):
@@ -62,5 +66,7 @@ def load_prev_session(main_widget, save_dir_input):
         logger1.error(e)
         print("Loading Failed please try again, if problem persists save directory " +
               "is corrupted")
+
+
 def export_timetraces(main_widget):
     createFileDialog(forOpen=False, isFolder=2)
