@@ -3,7 +3,7 @@ from PySide2.QtWidgets import *
 
 class Input(QFrame):
     def __init__(self, display_name, program_name, on_change_function, default_val,
-                 tool_tip, display_tool_tip =False):
+                 tool_tip, display_tool_tip=False, show_name=True):
         super().__init__()
         self.program_name = program_name
         self.input_box_1 = None
@@ -11,11 +11,14 @@ class Input(QFrame):
         self.default_val = default_val
         self.display_name = display_name
         self.layout_main = QVBoxLayout()
+        self.layout_main.setContentsMargins(2, 2, 2, 2)
         self.layout_h = QHBoxLayout()
-        temp_lable = QLabel()
-        temp_lable.setText(display_name)
-        temp_lable.setToolTip(tool_tip)
-        self.layout_h.addWidget(temp_lable)
+        self.layout_h.setContentsMargins(0, 0, 0, 0)
+        if show_name:
+            temp_label = QLabel()
+            temp_label.setText(display_name)
+            temp_label.setToolTip(tool_tip)
+            self.layout_h.addWidget(temp_label)
         self.on_change_function = on_change_function
         self.layout_main.addLayout(self.layout_h)
         if display_tool_tip:
@@ -34,13 +37,8 @@ class Input(QFrame):
 
     def current_state(self):
         pass
+
     def set_default_val(self):
         pass
 
-
-
 # TODO implement way to check spatial boxes square
-
-
-
-
